@@ -42,8 +42,8 @@ from openpyxl.reader.excel import load_workbook
 # constants
 
 __major__ = 1  # for major interface/format changes
-__minor__ = 5  # for minor interface/format changes
-__release__ = 8  # for tweaks, bug-fixes, or development
+__minor__ = 6  # for minor interface/format changes
+__release__ = 2  # for tweaks, bug-fixes, or development
 
 __version__ = '%d.%d.%d' % (__major__, __minor__, __release__)
 
@@ -51,7 +51,7 @@ __author__ = 'Eric Gazoni'
 __license__ = 'MIT/Expat'
 __author_email__ = 'eric.gazoni@gmail.com'
 __maintainer_email__ = 'openpyxl-users@googlegroups.com'
-__url__ = 'http://bitbucket.org/ericgazoni/openpyxl/wiki/Home'
+__url__ = 'http://openpyxl.readthedocs.org'
 __downloadUrl__ = "http://bitbucket.org/ericgazoni/openpyxl/downloads"
 
 __all__ = ('reader', 'shared', 'writer',)
