@@ -50,17 +50,27 @@ except NameError:
     # Python 3
     unicode = str
 
-def repair_central_directory(zipFile):
-    ''' trims trailing data from the central directory 
+CENTRAL_DIRECTORY_SIGNATURE = '\x50\x4b\x05\x06'
+
+def repair_central_directory(zipFile, is_file_instance):
+    ''' trims trailing data from the central directory
     code taken from http://stackoverflow.com/a/7457686/570216, courtesy of Uri Cohen
     '''
-    f = open(zipFile, 'r+b')
+    from StringIO import StringIO
+
+    f = zipFile if is_file_instance else open(zipFile, 'r+b')
     data = f.read().decode("utf-8")
-    pos = data.find('\x50\x4b\x05\x06') # End of central directory signature  
+    pos = data.find(CENTRAL_DIRECTORY_SIGNATURE)  # End of central directory signature
     if (pos > 0):
-        f.seek(pos + 22)   # size of 'ZIP end of central directory record' 
-        f.truncate()
-        f.close()
+        sio = StringIO(data)
+        sio.seek(pos + 22)  # size of 'ZIP end of central directory record'
+        sio.truncate()
+        sio.seek(0)
+        return sio
+
+    f.seek(0)
+    return f
+
 
 def load_workbook(filename, use_iterators=False):
     """Open the given filename and return the workbook
@@ -88,6 +98,7 @@ def load_workbook(filename, use_iterators=False):
         from io import BufferedReader
         is_file_instance = isinstance(filename, BufferedReader)
 
+
     if is_file_instance:
         # fileobject must have been opened with 'rb' flag
         # it is required by zipfile
@@ -98,8 +109,8 @@ def load_workbook(filename, use_iterators=False):
         archive = ZipFile(filename, 'r', ZIP_DEFLATED)
     except BadZipfile:
         try:
-            repair_central_directory(filename)
-            archive = ZipFile(filename, 'r', ZIP_DEFLATED)
+            f = repair_central_directory(filename, is_file_instance)
+            archive = ZipFile(f, 'r', ZIP_DEFLATED)
         except BadZipfile:
             e = exc_info()[1]
             raise InvalidFileException(unicode(e))
@@ -134,7 +145,11 @@ def _load_workbook(wb, archive, filename, use_iterators):
         string_table = read_string_table(archive.read(ARC_SHARED_STRINGS))
     except KeyError:
         string_table = {}
-    wb.loaded_theme = archive.read(ARC_THEME)
+    try:
+        wb.loaded_theme = archive.read(ARC_THEME)  # some writers don't output a theme, live with it (fixes #160)
+    except KeyError:
+        assert wb.loaded_theme == None, "even though the theme information is missing there is a theme object ?"
+
     style_table = read_style_table(archive.read(ARC_STYLE))
 
     wb.properties.excel_base_date = read_excel_base_date(xml_source=archive.read(ARC_WORKBOOK))
