@@ -1,6 +1,6 @@
 # file openpyxl/tests/test_cell.py
 
-# Copyright (c) 2010 openpyxl
+# Copyright (c) 2010-2011 openpyxl
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,10 +21,10 @@
 # THE SOFTWARE.
 #
 # @license: http://www.opensource.org/licenses/mit-license.php
-# @author: Eric Gazoni
+# @author: see AUTHORS file
 
 # Python stdlib imports
-from datetime import time, datetime
+from datetime import time, datetime, timedelta
 
 # 3rd party imports
 from nose.tools import eq_, raises, assert_raises #pylint: disable=E0611
@@ -34,11 +34,22 @@ from openpyxl.worksheet import Worksheet
 from openpyxl.workbook import Workbook
 from openpyxl.shared.exc import ColumnStringIndexException, \
         CellCoordinatesException, DataTypeException
+from openpyxl.shared.date_time import CALENDAR_WINDOWS_1900
 from openpyxl.cell import column_index_from_string, \
         coordinate_from_string, get_column_letter, Cell, absolute_coordinate
 
 import decimal
 
+def build_dummy_worksheet():
+
+    class Ws(object):
+        class Wb(object):
+            excel_base_date = CALENDAR_WINDOWS_1900
+        encoding = 'utf-8'
+        parent = Wb()
+
+    return Ws()
+
 
 def test_coordinates():
     column, row = coordinate_from_string('ZF46')
@@ -93,19 +104,18 @@ def test_column_letter():
 
 
 def test_initial_value():
-    cell = Cell(None, 'A', 1, value='17.5')
+    ws = build_dummy_worksheet()
+    cell = Cell(ws, 'A', 1, value='17.5')
     eq_(cell.TYPE_NUMERIC, cell.data_type)
 
 
-class TestCellValueTypes():
+class TestCellValueTypes(object):
 
     @classmethod
     def setup_class(cls):
 
-        class Ws(object):
-            encoding = 'utf-8'
-
-        cls.cell = Cell(Ws(), 'A', 1)
+        ws = build_dummy_worksheet()
+        cls.cell = Cell(ws, 'A', 1)
 
     def test_1st(self):
         eq_(self.cell.TYPE_NULL, self.cell.data_type)
@@ -157,9 +167,8 @@ class TestCellValueTypes():
 
 
 def test_data_type_check():
-    class Ws(object):
-            encoding = 'utf-8'
-    cell = Cell(Ws(), 'A', 1)
+    ws = build_dummy_worksheet()
+    cell = Cell(ws, 'A', 1)
     cell.bind_value(None)
     eq_(Cell.TYPE_NULL, cell._data_type)
 
@@ -174,7 +183,8 @@ def test_data_type_check():
 
 @raises(DataTypeException)
 def test_set_bad_type():
-    cell = Cell(None, 'A', 1)
+    ws = build_dummy_worksheet()
+    cell = Cell(ws, 'A', 1)
     cell.set_value_explicit(1, 'q')
 
 
@@ -193,6 +203,16 @@ def test_time():
         yield check_time, raw_value, coerced_value
 
 
+def test_timedelta():
+
+    wb = Workbook()
+    ws = Worksheet(wb)
+    cell = Cell(ws, 'A', 1)
+    cell.value = timedelta(days=1, hours=3)
+    eq_(cell.value, 1.125)
+    eq_(cell.TYPE_NUMERIC, cell.data_type)
+
+
 def test_date_format_on_non_date():
     wb = Workbook()
     ws = Worksheet(wb)
