@@ -47,6 +47,10 @@ class TestDims(TestWorksheet):
 
             eq_(ws._dimensions, self.expected[i])
 
+    def test_get_highest_column_iter(self):
+        wb = self._open_wb()
+        ws = wb.worksheets[0]
+        eq_(ws.get_highest_column(), 7)
 
 class TestText(TestWorksheet):
     sheet_name = 'Sheet1 - Text'
