@@ -1,7 +1,7 @@
 # file openpyxl/tests/test_worksheet.py
 
 # Copyright (c) 2010-2011 openpyxl
-# 
+#
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
@@ -30,7 +30,7 @@ from nose.tools import eq_, raises, assert_raises
 from openpyxl.workbook import Workbook
 from openpyxl.worksheet import Worksheet, Relationship, flatten
 from openpyxl.writer.worksheet import write_worksheet
-from openpyxl.cell import Cell
+from openpyxl.cell import Cell, coordinate_from_string
 from openpyxl.shared.exc import CellCoordinatesException, \
         SheetTitleException, InsufficientCoordinatesException, \
         NamedRangeException
@@ -139,7 +139,7 @@ class TestWorksheet(object):
         ws.cell('B2').value = '0'
         ws.cell('C4').value = 0
         ws.garbage_collect()
-        eq_(ws.get_cell_collection(), [ws.cell('B2'), ws.cell('C4')])
+        eq_(list(ws.get_cell_collection()), [ws.cell('B2'), ws.cell('C4')])
 
     def test_hyperlink_relationships(self):
         ws = Worksheet(self.wb)
@@ -254,6 +254,28 @@ class TestWorksheet(object):
         xml_string = write_worksheet(ws, None, None)
         assert '<pageMargins left="2.00" right="2.00" top="2.00" bottom="2.00" header="1.50" footer="1.50"></pageMargins>' in xml_string
 
+        ws = Worksheet(self.wb)
+        xml_string = write_worksheet(ws, None, None)
+        assert '<pageMargins' not in xml_string
+
+    def test_merge(self):
+        ws = Worksheet(self.wb)
+        string_table = {'':'', 'Cell A1':'Cell A1', 'Cell B1':'Cell B1'}
+
+        ws.cell('A1').value = 'Cell A1'
+        ws.cell('B1').value = 'Cell B1'
+        xml_string = write_worksheet(ws, string_table, None)
+        assert '<c r="B1" t="s"><v>Cell B1</v></c>' in xml_string
+
+        ws.merge_cells('A1:B1')
+        xml_string = write_worksheet(ws, string_table, None)
+        assert '<c r="B1" t="s"><v>Cell B1</v></c>' not in xml_string
+        assert '<mergeCells count="1"><mergeCell ref="A1:B1"></mergeCell></mergeCells>' in xml_string
+
+        ws.unmerge_cells('A1:B1')
+        xml_string = write_worksheet(ws, string_table, None)
+        assert '<mergeCell ref="A1:B1"/>' not in xml_string
+
     def test_freeze(self):
         ws = Worksheet(self.wb)
         ws.freeze_panes = ws.cell('b2')
@@ -269,12 +291,71 @@ class TestWorksheet(object):
         assert ws.freeze_panes is None
 
     def test_printer_settings(self):
-
         ws = Worksheet(self.wb)
-        ws.set_printer_settings(Worksheet.PAPER_SIZE_LEGAL, Worksheet.ORIENTATION_LANDSCAPE)
+        ws.page_setup.orientation = ws.ORIENTATION_LANDSCAPE
+        ws.page_setup.paperSize = ws.PAPERSIZE_TABLOID
+        ws.page_setup.fitToPage = True
+        ws.page_setup.fitToHeight = 0
+        ws.page_setup.fitToWidth = 1
+        ws.page_setup.horizontalCentered = True
+        ws.page_setup.verticalCentered = True
         xml_string = write_worksheet(ws, None, None)
-        assert '<pageSetup paperSize="5" orientation="landscape"></pageSetup>' in xml_string
+        assert '<pageSetup orientation="landscape" paperSize="3" fitToHeight="0" fitToWidth="1"></pageSetup>' in xml_string
+        assert '<pageSetUpPr fitToPage="1"></pageSetUpPr>' in xml_string
+        assert '<printOptions horizontalCentered="1" verticalCentered="1">' in xml_string
 
         ws = Worksheet(self.wb)
         xml_string = write_worksheet(ws, None, None)
-        assert "<pageSetup paperSize" not in xml_string
+        assert "<pageSetup" not in xml_string
+        assert "<pageSetUpPr" not in xml_string
+        assert "<printOptions" not in xml_string
+
+    def test_header_footer(self):
+        ws = Worksheet(self.wb)
+        ws.header_footer.left_header.text = "Left Header Text"
+        ws.header_footer.center_header.text = "Center Header Text"
+        ws.header_footer.center_header.font_name = "Arial,Regular"
+        ws.header_footer.center_header.font_size = 6
+        ws.header_footer.center_header.font_color = "445566"
+        ws.header_footer.right_header.text = "Right Header Text"
+        ws.header_footer.right_header.font_name = "Arial,Bold"
+        ws.header_footer.right_header.font_size = 8
+        ws.header_footer.right_header.font_color = "112233"
+        ws.header_footer.left_footer.text = "Left Footer Text\nAnd &[Date] and &[Time]"
+        ws.header_footer.left_footer.font_name = "Times New Roman,Regular"
+        ws.header_footer.left_footer.font_size = 10
+        ws.header_footer.left_footer.font_color = "445566"
+        ws.header_footer.center_footer.text = "Center Footer Text &[Path]&[File] on &[Tab]"
+        ws.header_footer.center_footer.font_name = "Times New Roman,Bold"
+        ws.header_footer.center_footer.font_size = 12
+        ws.header_footer.center_footer.font_color = "778899"
+        ws.header_footer.right_footer.text = "Right Footer Text &[Page] of &[Pages]"
+        ws.header_footer.right_footer.font_name = "Times New Roman,Italic"
+        ws.header_footer.right_footer.font_size = 14
+        ws.header_footer.right_footer.font_color = "AABBCC"
+        xml_string = write_worksheet(ws, None, None)
+        assert '<headerFooter>' in xml_string
+        assert '<oddHeader>&amp;L&amp;"Calibri,Regular"&amp;K000000Left Header Text&amp;C&amp;"Arial,Regular"&amp;6&amp;K445566Center Header Text&amp;R&amp;"Arial,Bold"&amp;8&amp;K112233Right Header Text</oddHeader>' in xml_string
+        assert '<oddFooter>&amp;L&amp;"Times New Roman,Regular"&amp;10&amp;K445566Left Footer Text_x000D_And &amp;D and &amp;T&amp;C&amp;"Times New Roman,Bold"&amp;12&amp;K778899Center Footer Text &amp;Z&amp;F on &amp;A&amp;R&amp;"Times New Roman,Italic"&amp;14&amp;KAABBCCRight Footer Text &amp;P of &amp;N</oddFooter></headerFooter>' in xml_string
+        assert '</headerFooter>' in xml_string
+
+        ws = Worksheet(self.wb)
+        xml_string = write_worksheet(ws, None, None)
+        assert "<headerFooter>" not in xml_string
+        assert "<oddHeader>" not in xml_string
+        assert "<oddFooter>" not in xml_string
+
+
+class TestPositioning(object):
+    def test_point(self):
+        wb = Workbook()
+        ws = wb.get_active_sheet()
+        eq_(ws.point_pos(top=40, left=150), ('C', 3))
+
+    def test_roundtrip(self):
+        wb = Workbook()
+        ws = wb.get_active_sheet()
+        for address in ('A1', 'D52', 'X11'):
+            eq_(ws.point_pos(*ws.cell(address).anchor),
+                coordinate_from_string(address))
+
