@@ -77,6 +77,7 @@ def write_worksheet(worksheet, string_table, style_table):
     if worksheet.auto_filter:
         tag(doc, 'autoFilter', {'ref': worksheet.auto_filter})
     write_worksheet_mergecells(doc, worksheet)
+    write_worksheet_datavalidations(doc, worksheet)
     write_worksheet_hyperlinks(doc, worksheet)
 
     options = worksheet.page_setup.options
@@ -99,7 +100,7 @@ def write_worksheet(worksheet, string_table, style_table):
             tag(doc, 'oddFooter', None, worksheet.header_footer.getFooter())
         end_tag(doc, 'headerFooter')
 
-    if worksheet._charts:
+    if worksheet._charts or worksheet._images:
         tag(doc, 'drawing', {'r:id':'rId1'})
     end_tag(doc, 'worksheet')
     doc.endDocument()
@@ -198,7 +199,8 @@ def write_worksheet_data(doc, worksheet, string_table, style_table):
             value = cell._value
             coordinate = cell.get_coordinate()
             attributes = {'r': coordinate}
-            attributes['t'] = cell.data_type
+            if cell.data_type != cell.TYPE_FORMULA:
+                attributes['t'] = cell.data_type
             if coordinate in worksheet._styles:
                 attributes['s'] = '%d' % style_id_by_hash[
                         hash(worksheet._styles[coordinate])]
@@ -236,6 +238,24 @@ def write_worksheet_mergecells(doc, worksheet):
             tag(doc, 'mergeCell', attrs)
         end_tag(doc, 'mergeCells')
 
+def write_worksheet_datavalidations(doc, worksheet):
+    """ Write data validation(s) to xml."""
+    # Filter out "empty" data-validation objects (i.e. with 0 cells)
+    required_dvs = [x for x in worksheet._data_validations
+                    if len(x.cells) or len(x.ranges)]
+    count = len(required_dvs)
+    if count == 0:
+        return
+
+    start_tag(doc, 'dataValidations', {'count': str(count)})
+    for data_validation in required_dvs:
+        start_tag(doc, 'dataValidation', data_validation.generate_attributes_map())
+        if data_validation.formula1:
+            tag(doc, 'formula1', body=data_validation.formula1)
+        if data_validation.formula2:
+            tag(doc, 'formula2', body=data_validation.formula2)
+        end_tag(doc, 'dataValidation')
+    end_tag(doc, 'dataValidations')
 
 def write_worksheet_hyperlinks(doc, worksheet):
     """Write worksheet hyperlinks to xml."""
@@ -263,7 +283,7 @@ def write_worksheet_rels(worksheet, idx):
         if rel.target_mode:
             attrs['TargetMode'] = rel.target_mode
         SubElement(root, 'Relationship', attrs)
-    if worksheet._charts:
+    if worksheet._charts or worksheet._images:
         attrs = {'Id' : 'rId1',
             'Type' : 'http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing',
             'Target' : '../drawings/drawing%s.xml' % idx }
